"use strict";
/*********************************
 File:       sentry.js
 Function:   Does Sentry logging
 Copyright:  Bertco LLC
 Date:       2021-06-08
 Author:     mkahn
 **********************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.captureException = exports.logFatal = exports.logCritical = exports.log = void 0;
var Sentry = require("@sentry/react-native");
var react_native_1 = require("@sentry/react-native");
var types_1 = require("./types");
var helpers_1 = require("./helpers");
// Severity has additional levels like Fatal and Critical that we're not using
var mapLogLevelToSeverity = function (logLevel) {
    switch (logLevel) {
        case types_1.LogLevel.silent:
        case types_1.LogLevel.silly:
        case types_1.LogLevel.debug:
            return react_native_1.Severity.Debug;
        case types_1.LogLevel.warn:
            return react_native_1.Severity.Warning;
        case types_1.LogLevel.info:
            return react_native_1.Severity.Log;
        case types_1.LogLevel.error:
            return react_native_1.Severity.Error;
    }
    return react_native_1.Severity.Log;
};
// if it's a primitive, sent it directly, otherwise stringify
var reduceToSentryMessage = function (message) { return helpers_1.isStringOrNumber(message) ? "" + message : JSON.stringify(message); };
var captureMessage = function (message, severity) {
    Sentry.captureMessage(reduceToSentryMessage(message), severity);
};
var log = function (message, logLevel) {
    captureMessage(message, mapLogLevelToSeverity(logLevel));
};
exports.log = log;
// not sure these will be used, but here you go
var logCritical = function (message) {
    captureMessage(message, react_native_1.Severity.Critical);
};
exports.logCritical = logCritical;
var logFatal = function (message) {
    captureMessage(message, react_native_1.Severity.Fatal);
};
exports.logFatal = logFatal;
// this is probably not useful
var captureException = function (e) {
    Sentry.captureException(e);
};
exports.captureException = captureException;
//# sourceMappingURL=sentry.js.map