/*********************************
 File:       xlogger.ts
 Function:   Xlogger in typescript
 Copyright:  Bertco LLC
 Date:       2020-02-14
 Author:     mkahn
 **********************************/
import { LogLevel, Message, XLoggerConfig, ReactotronInstance } from './types';
export declare const setReactronInstance: (instance: ReactotronInstance) => void;
export declare const configure: (settings: Partial<XLoggerConfig>) => void;
export declare type BypassParams = {
    bypassReactotron: boolean;
    bypassSentry: boolean;
};
/**
 * Sets the logLevel, if it is in the list of legit ones above.
 * @param level
 */
export declare const setLogLevel: (level: LogLevel) => void;
/**
 * Enables/disables Reactotron logging
 * @param shouldUse
 */
export declare const setUseReactotron: (shouldUse: boolean) => void;
/**
 * Enables/disables Sentry logging
 * @param shouldUse
 */
export declare const setUseSentry: (shouldUse: boolean) => void;
/**
 * Maps logWarn to console.warn, and logError to console.error
 * @param shouldUse
 */
export declare const setUseCorrespondingConsoleMethod: (shouldUse: boolean) => void;
/**
 * Always log out, bypass log level unless silent.
 * @param message
 * @param bypassParams
 */
export declare const out: (message: Message, bypassParams?: BypassParams) => void;
export declare const logSilly: (message: Message, bypassParams?: BypassParams) => void;
export declare const logVerbose: (message: Message, bypassParams?: BypassParams) => void;
export declare const logInfo: (message: Message, bypassParams?: BypassParams) => void;
export declare const logWarn: (message: Message, bypassParams?: BypassParams) => void;
export declare const logError: (message: Message, bypassParams?: BypassParams) => void;
export declare const logDebug: (message: Message, bypassParams?: BypassParams) => void;
export declare const reactotron: {
    log: (message: Message) => void;
    logImportant: (message: Message) => void;
    display: (object: Message) => void;
};
export declare const sentry: {
    log: (message: Message | import("@sentry/types").Exception, logLevel: LogLevel) => void;
    logFatal: (message: Message) => void;
    logCritical: (message: Message) => void;
};
export declare const silly: (message: Message, bypassParams?: BypassParams) => void;
export declare const verbose: (message: Message, bypassParams?: BypassParams) => void;
export declare const info: (message: Message, bypassParams?: BypassParams) => void;
export declare const warn: (message: Message, bypassParams?: BypassParams) => void;
export declare const error: (message: Message, bypassParams?: BypassParams) => void;
export declare const debug: (message: Message, bypassParams?: BypassParams) => void;
export declare const log: (message: Message, bypassParams?: BypassParams) => void;
